# Others


:::{card} 
##### How do I change my home directory?
^^^
  - Navigate to the `Help` menu and find the `Experiment Home` option
  - Follow the prompt to change your home directory

  :::{figure} images/help_exp-home.png
  :::

:::


:::{card}
##### How do I manage my model directories?
^^^
Currently, existing model directories can only be managed outside of the plugin's interface using the regular file explorer application specific to your system

:::

<br>